/* $Id: applanix.sql,v 1.23 2004/10/11 10:42:42 mario Exp $
 *
 **************************************************************************
 * mg.applanix, Copyright (C) by Mario Gleirscher                         *
 * mg.applanix comes with ABSOLUTELY NO WARRANTY; This is free software,  *
 * and you are welcome to redistribute it under certain conditions;       *
 * view the file COPYING for details.                                     *
 **************************************************************************
 *
 * SQL script for creation/installation of the database of
 * mg.applanix on a MySQL server
 *
 * Important: %apx_dbname% and %apx_dbtableprefix% will be substituted by 
 * the installation routine. The **nq** markers as well serve the 
 * installation routine.
 *
 * Prior to the installation routine you need to manually perform:
 * CREATE USER '%apx_dbuser%'@'%apx_dbserver%' IDENTIFIED BY '%apx_dbpw%';
 * GRANT ALL PRIVILEGES ON %apx_db%.* TO '%apx_dbuser%'@'%apx_dbserver%' WITH GRANT OPTION;
 *
 **nq**
 * SET SESSION lc_time_names = 'de_AT';
 * 
 **nq**
 * SET NAMES 'utf8';
 * 
 * see http://dev.mysql.com/doc/refman/5.5/en/charset-connection.html
 * and http://dev.mysql.com/doc/refman/5.5/en/charset-conversion.html
 */

/**nq**/
CREATE DATABASE IF NOT EXISTS `%apx_dbname%`;

/**nq**/
USE `%apx_dbname%`;

/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%rooms`
(
    `room_id` SMALLINT UNSIGNED NOT NULL,
    `roomnumber` VARCHAR(15),
    `floor` TINYINT DEFAULT '0',
    `type`  TINYINT UNSIGNED DEFAULT '0',
    `house` VARCHAR(50),
    `object_id` SMALLINT UNSIGNED,
    `name` VARCHAR(50),
    `capacity` TINYINT UNSIGNED DEFAULT '1' NOT NULL,
    `size` FLOAT,
    `equipment` VARCHAR(250),
    `phone` VARCHAR(30),
    `safecode` VARCHAR(20),
    `price_top` SMALLINT UNSIGNED,
    `price_bottom` SMALLINT UNSIGNED,
    `sketchfile` VARCHAR(50),
    `showit` TINYINT UNSIGNED DEFAULT '1' NOT NULL,
    `notice` VARCHAR(250),

    PRIMARY KEY ( `room_id` ),

    KEY idx_appnr ( roomnumber ),
    KEY idx_object_id ( object_id )
)
COMMENT = 'Raumdaten';


/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%objects`
(
    `object_id` SMALLINT UNSIGNED NOT NULL,
    `objnr` VARCHAR(15),
    `type` TINYINT UNSIGNED DEFAULT '0' NOT NULL,
    `name` VARCHAR(50),
    `address` VARCHAR(150),
    `phone`  VARCHAR(30),
    `floors` TINYINT UNSIGNED DEFAULT '0' NOT NULL,
    `notice` VARCHAR(250),
    `showit` TINYINT UNSIGNED DEFAULT '1' NOT NULL,

    PRIMARY KEY ( `object_id` ),

    KEY idx_objnr ( objnr )
)
COMMENT = 'Mietobjekte';


/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%bookings`
(
    `booking_id` 		SMALLINT UNSIGNED NOT NULL,
    `is_inquiry` 		TINYINT UNSIGNED DEFAULT '0',
    `bill_lfnr` 		MEDIUMINT UNSIGNED,
    `bill_date` 		DATE DEFAULT NULL,
    `ba_usebilladdress` TINYINT UNSIGNED DEFAULT '1' NOT NULL,
    `ba_addressee` 		VARCHAR( 100 ),
    `ba_street` 		VARCHAR( 50 ),
    `ba_zip` 			VARCHAR( 50 ),
    `ba_place` 			VARCHAR( 100 ),
    `ba_country_id` 	TINYINT UNSIGNED, 
    `guestcard_nr` 		VARCHAR( 20 ),
    `booking_type` 		TINYINT UNSIGNED, 
    `customer_id` 		SMALLINT UNSIGNED NOT NULL,
    `room_id` 			SMALLINT UNSIGNED NOT NULL,
    `date_begin` 		DATE NOT NULL,
    `date_end` 			DATE NOT NULL,
    `timeofarrival` 	TINYINT,  
    `meals` 			TINYINT UNSIGNED DEFAULT '0', 
    `persons` 			TINYINT UNSIGNED DEFAULT '1' NOT NULL,
    `children` 			TINYINT UNSIGNED DEFAULT '0', 
    `priceperday` 		DECIMAL(10,3) 		DEFAULT '0', 
    `daystopay` 		TINYINT UNSIGNED 	DEFAULT '1' NOT NULL ,
    `cleansingcosts` 	DECIMAL(10,3) 		DEFAULT '0' NOT NULL ,
    `phonecosts` 		DECIMAL(10,3) 		DEFAULT '0' NOT NULL ,
    `breadcosts` 		DECIMAL(10,3) 		DEFAULT '0' NOT NULL ,
    `prepayment` 		DECIMAL(10,3) 		DEFAULT '0', 
    `misccosts` 		DECIMAL(10,3) 		DEFAULT '0' NOT NULL ,
    `ortstaxe` 			DECIMAL(10,3) 		DEFAULT '0',
    `notice` 			TEXT,
    `inetaccess`		VARCHAR( 100 ),
    `payed` 			TINYINT UNSIGNED DEFAULT '0',
    `checkedin` 		TINYINT UNSIGNED DEFAULT '0',
    `confirmed` 		TINYINT UNSIGNED DEFAULT '0',
    `reported` 			TINYINT UNSIGNED DEFAULT '0',
    `showit` 			TINYINT UNSIGNED DEFAULT '1' NOT NULL,
    `provider`			TINYINT UNSIGNED DEFAULT '0', 
    `wife_firstname` 	VARCHAR( 30 ),
    `wife_birthdate` 	DATE,
    `children_firstnames` VARCHAR( 150 ),
    `children_birthdates` VARCHAR( 150 ),
    `lastupdated` 		DATE, 
    `lasteditor` TINYINT UNSIGNED,
    `created` DATE, 
    `firsteditor` TINYINT UNSIGNED,

    PRIMARY KEY ( `booking_id` ),

    KEY idx_customer_id ( customer_id ),
    KEY idx_ba_country_id ( ba_country_id )
)
COMMENT = 'Buchungsdaten';


/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%seasons`
(
    `season_id` SMALLINT UNSIGNED NOT NULL ,
    `maintype` TINYINT UNSIGNED NOT NULL ,
    `subtype` TINYINT UNSIGNED NOT NULL ,
    `start` DATE NOT NULL ,
    `priceperday` DOUBLE PRECISION, 
    `end` DATE NOT NULL ,

    PRIMARY KEY ( `season_id` ),

    KEY idx_season_id ( season_id )
)
COMMENT = 'Saisonsdaten';


/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%countries`
(
    `country_id` TINYINT UNSIGNED NOT NULL ,
    `shortcut` VARCHAR( 10 ) ,
    `countryname_de` VARCHAR( 100 ) ,
    `countryname_en` VARCHAR( 100 ) ,
    `priorshow` TINYINT UNSIGNED DEFAULT '0' NOT NULL ,
    `countrycode` TINYINT UNSIGNED,
    `oestat_id` SMALLINT UNSIGNED,
    `countrygroup` TINYINT UNSIGNED,

    PRIMARY KEY ( `country_id` ),

    KEY idx_priorshow ( priorshow )
)
COMMENT = 'Laenderdaten';


/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%customers`
(
    `customer_id` SMALLINT UNSIGNED NOT NULL,
    `entrytype` TINYINT UNSIGNED DEFAULT '0' NOT NULL ,
    `sex` TINYINT UNSIGNED DEFAULT '0',  
    `male` TINYINT UNSIGNED DEFAULT '1' NOT NULL ,
    `title` VARCHAR( 30 ),
    `firstname` VARCHAR( 50 ),
    `lastname` VARCHAR( 50 ),
    `nickname` VARCHAR( 30 ),
    `notice` TEXT,
    `address` VARCHAR( 250 ),
    `country_id` TINYINT UNSIGNED NOT NULL,
    `nationality` TINYINT UNSIGNED,
    `zip` VARCHAR( 20 ),
    `place` VARCHAR( 50 ),
    `phone` VARCHAR( 50 ),
    `phone2` VARCHAR( 50 ),
    `mobile` VARCHAR( 50 ),
    `fax` VARCHAR( 50 ),
    `email` VARCHAR( 100 ),
    `email2` VARCHAR( 100 ),
    `creditcardnr` VARCHAR( 30 ),
    `bankaccount` VARCHAR( 40 ),
    `passportnr` VARCHAR( 150 ),
    `im_id` VARCHAR( 30 ),
    `im_type` TINYINT UNSIGNED DEFAULT '0', 
    `birthdate` DATE,
    `job` VARCHAR( 50 ),
    `homepage` VARCHAR( 100 ),
    `image` 		VARCHAR( 50 ),
    `rating` 		TINYINT UNSIGNED DEFAULT '0',
    `lastupdated` 	DATE, 
    `lasteditor` TINYINT UNSIGNED,
    `created` DATE, 
    `firsteditor` TINYINT UNSIGNED,

    PRIMARY KEY ( `customer_id` ),

    KEY idx_country_id ( country_id ),
    KEY idx_firstname ( firstname( 3 ) ),
    KEY idx_lastname ( lastname( 3 ) ),
    KEY idx_place ( place( 3 ) )
)
COMMENT = 'Kundendaten';


/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%customer_roles`
(
	`fk_customer_id` SMALLINT UNSIGNED,
	`fk_booking_id` SMALLINT UNSIGNED,
	`report_role` VARCHAR( 2 ) DEFAULT 'HG',
	
	PRIMARY KEY ( `fk_customer_id`, `fk_booking_id` ),
	
	FOREIGN KEY ( `fk_customer_id` ) 
		REFERENCES `%apx_dbtableprefix%customers` ( `customer_id` ),
	FOREIGN KEY ( `fk_booking_id` ) 
		REFERENCES `%apx_dbtableprefix%bookings` ( `booking_id` )
)
COMMENT = 'Rollen von Kunden in Gaestemeldungen';


/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%dates`
(
    `date_id` SMALLINT UNSIGNED NOT NULL,
    `reminder` TINYINT UNSIGNED DEFAULT '1' NOT NULL ,
    `thedate` DATE NOT NULL ,
    `priority` TINYINT UNSIGNED DEFAULT '0' NOT NULL ,
    `time` TIME,
    `notice` TEXT,
    `showit` TINYINT UNSIGNED DEFAULT '1' NOT NULL ,
    `lastupdated` DATE, 
    `lasteditor` TINYINT UNSIGNED,
    `created` DATE, 
    `firsteditor` TINYINT UNSIGNED,

    PRIMARY KEY ( `date_id` ),

    KEY idx_reminder ( reminder )
)
COMMENT = 'Termindaten';


/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%editors`
(
    `editor_id` TINYINT UNSIGNED NOT NULL,
    `firstname` VARCHAR( 30 ) ,
    `lastname` VARCHAR( 30 ) ,
    `login` VARCHAR( 10 ) NOT NULL ,
    `password` VARCHAR( 35 ) NOT NULL ,
    `email` VARCHAR( 100 ) ,
    `usertype` TINYINT UNSIGNED DEFAULT '0' NOT NULL ,
    `active` TINYINT UNSIGNED DEFAULT '1' NOT NULL ,
    `startpage` TINYINT UNSIGNED DEFAULT '10',
    `l10n` VARCHAR( 6 ) DEFAULT 'en_US', 

    PRIMARY KEY ( `editor_id` ),
    UNIQUE ( `login` ),

    KEY idx_login ( login( 3 ) ),
    KEY idx_password ( password( 3 ) )
)
COMMENT = 'Applanix-Bearbeiterdaten';


/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%editorsessions`
(
    `session_id` VARCHAR( 50 ) NOT NULL,
    `editor_id` TINYINT UNSIGNED NOT NULL,
    `created` INT UNSIGNED NOT NULL,

    PRIMARY KEY idx_session_id ( session_id( 20 ) ),

	FOREIGN KEY ( `editor_id` ) 
		REFERENCES `%apx_dbtableprefix%editors` ( `editor_id` )
)
COMMENT = 'Applanix-Bearbeitersession-Daten';


/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%mails`
(
    `mail_id` MEDIUMINT UNSIGNED NOT NULL ,
    `customer_id` SMALLINT UNSIGNED NOT NULL ,
    `composed` DATETIME NOT NULL ,
    `sendto` VARCHAR( 80 ) NOT NULL ,
    `replyto` VARCHAR( 80 ) ,
    `cc` VARCHAR( 80 ) ,
    `subject` VARCHAR( 200 ) ,
    `text` MEDIUMTEXT,

    PRIMARY KEY ( `mail_id` ),

    KEY idx_customer_id ( customer_id )
)
COMMENT = 'Kundenmails';


/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%forum`
(
    `message_id` MEDIUMINT UNSIGNED NOT NULL ,
    `thread_mother` MEDIUMINT UNSIGNED,
    `subject` VARCHAR( 200 ),
    `message` MEDIUMTEXT,
    `showit` TINYINT UNSIGNED DEFAULT '1' NOT NULL,
    `lastupdated` DATE, 
    `lasteditor` TINYINT UNSIGNED,
    `created` DATE, 
    `firsteditor` TINYINT UNSIGNED,

    PRIMARY KEY ( `message_id` ),

    KEY idx_thread_mother ( thread_mother ),
    KEY idx_subject ( subject )
)
COMMENT = 'applanix Benutzerforum';


/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%labelsets`
(
    `labelset_id` MEDIUMINT UNSIGNED NOT NULL ,
    `labelset_name` VARCHAR( 50 ) NOT NULL,
    `customers` TEXT,

    PRIMARY KEY ( `labelset_id` ),

    KEY idx_customers ( customers( 10 ) )
)
COMMENT = 'Ettikettensaetze';

/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%bk_entries`
(
    `entry_id` MEDIUMINT UNSIGNED NOT NULL,
    `account_id` SMALLINT UNSIGNED NOT NULL,
    `custom_id` VARCHAR( 10 ),
    `entry_date` DATE NOT NULL,
    `amount` DOUBLE PRECISION DEFAULT '0' NOT NULL,
    `description` VARCHAR( 255 ),
    `type` TINYINT UNSIGNED,
    `active` TINYINT UNSIGNED DEFAULT '1' NOT NULL,
    `lastupdated` DATE, 
    `lasteditor` TINYINT UNSIGNED,
    `created` DATE, 
    `firsteditor` TINYINT UNSIGNED,

    PRIMARY KEY ( `entry_id` ),

    KEY idx_account_id ( account_id ),
    KEY idx_description ( description( 20 ) )
)
COMMENT = 'Buchhaltung - Posten';

/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%bk_accounts`
(
    `account_id` SMALLINT UNSIGNED NOT NULL,
    `custom_id` VARCHAR( 32 ),
    `label` VARCHAR( 128 ),
    `description` TEXT,
    `type` TINYINT UNSIGNED,
    `lastupdated` DATE, 
    `lasteditor` TINYINT UNSIGNED,
    `created` DATE, 
    `firsteditor` TINYINT UNSIGNED,

    PRIMARY KEY ( `account_id` ),

    KEY idx_custom_id ( custom_id ),
    KEY idx_label ( label )
)
COMMENT = 'Buchhaltung - Konten';

/**nq**/
CREATE TABLE IF NOT EXISTS `%apx_dbtableprefix%bk_entries_bookings`
(
    `entry_id` MEDIUMINT UNSIGNED NOT NULL,
    `booking_id` SMALLINT UNSIGNED NOT NULL,

    PRIMARY KEY ( `entry_id`, `booking_id` )
)
COMMENT = 'Buchhaltung - Abbildung Posten auf Buchungen';



/**nq**/
INSERT IGNORE
INTO %apx_dbtableprefix%rooms
( room_id, roomnumber, object_id, name, capacity, showit )
VALUES
( 0, '', 0, 'nicht zugeordnet (Sys.obj.)', 0, 0 );


/**nq**/
INSERT IGNORE
INTO %apx_dbtableprefix%objects
( object_id, objnr, type, name, showit )
VALUES
( 0, 0, 0, 'nicht zugeordnet (Sys.obj.)', 1 );


/**nq**/
INSERT IGNORE
INTO %apx_dbtableprefix%editors
( editor_id, firstname, lastname, login, password, usertype, active )
VALUES
( 0, 'initial', 'administrator', 'admin', '72d46e3f10b4d10c7b17d3d8903c2cf9', 0, 1 );
/* Login: admin, Passwort: applanix */


/**nq**/
INSERT IGNORE
INTO %apx_dbtableprefix%countries
( country_id, priorshow )
VALUES
( 0, 1 );
